# pyright: reportUnusedImport=false
import struct
from typing import Optional, Self, Sequence
from .. import abcs
from ..core import Request, serialize_bytes_to
_bytes = bytes | bytearray | memoryview
def get_messages(*, id: Sequence[abcs.InputMessage]) -> Request[abcs.messages.Messages]:
    _buffer = bytearray(b'\x06e\xc6c')
    _buffer += struct.pack('<ii', 0x1cb5c415, len(id))
    for _t0 in id:
      _t0._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_dialogs(*, exclude_pinned: bool, folder_id: Optional[int], offset_date: int, offset_id: int, offset_peer: abcs.InputPeer, limit: int, hash: int) -> Request[abcs.messages.Dialogs]:
    _buffer = bytearray(b'O\xcb\xf4\xa0')
    flags = (1 if exclude_pinned else 0) | (0 if folder_id is None else 2)
    _buffer += struct.pack('<I', flags)
    if folder_id is not None:
      _buffer += struct.pack(f'<i', folder_id)
    _buffer += struct.pack('<ii', offset_date, offset_id)
    offset_peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<iq', limit, hash)
    return Request(b'' + _buffer)
def get_history(*, peer: abcs.InputPeer, offset_id: int, offset_date: int, add_offset: int, limit: int, max_id: int, min_id: int, hash: int) -> Request[abcs.messages.Messages]:
    _buffer = bytearray(b'\xc5\xe6#D')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<iiiiiiq', offset_id, offset_date, add_offset, limit, max_id, min_id, hash)
    return Request(b'' + _buffer)
def search(*, peer: abcs.InputPeer, q: str, from_id: Optional[abcs.InputPeer], top_msg_id: Optional[int], filter: abcs.MessagesFilter, min_date: int, max_date: int, offset_id: int, add_offset: int, limit: int, max_id: int, min_id: int, hash: int) -> Request[abcs.messages.Messages]:
    _buffer = bytearray(b'b\xa7\xfd\xa0')
    flags = (0 if from_id is None else 1) | (0 if top_msg_id is None else 2)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, q.encode('utf-8'))
    if from_id is not None:
      from_id._write_boxed_to(_buffer)
    if top_msg_id is not None:
      _buffer += struct.pack(f'<i', top_msg_id)
    filter._write_boxed_to(_buffer)
    _buffer += struct.pack('<iiiiiiiq', min_date, max_date, offset_id, add_offset, limit, max_id, min_id, hash)
    return Request(b'' + _buffer)
def read_history(*, peer: abcs.InputPeer, max_id: int) -> Request[abcs.messages.AffectedMessages]:
    _buffer = bytearray(b':m0\x0e')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', max_id)
    return Request(b'' + _buffer)
def delete_history(*, just_clear: bool, revoke: bool, peer: abcs.InputPeer, max_id: int, min_date: Optional[int], max_date: Optional[int]) -> Request[abcs.messages.AffectedHistory]:
    _buffer = bytearray(b'*\x92\x8f\xb0')
    flags = (1 if just_clear else 0) | (2 if revoke else 0) | (0 if min_date is None else 4) | (0 if max_date is None else 8)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', max_id)
    if min_date is not None:
      _buffer += struct.pack(f'<i', min_date)
    if max_date is not None:
      _buffer += struct.pack(f'<i', max_date)
    return Request(b'' + _buffer)
def delete_messages(*, revoke: bool, id: Sequence[int]) -> Request[abcs.messages.AffectedMessages]:
    _buffer = bytearray(b'\xd2\x95\x8e\xe5')
    flags = (1 if revoke else 0)
    _buffer += struct.pack('<I', flags)
    _buffer += struct.pack('<ii', 0x1cb5c415, len(id))
    _buffer += struct.pack(f'<{len(id)}i', *id)
    return Request(b'' + _buffer)
def received_messages(*, max_id: int) -> Request[Sequence[abcs.ReceivedNotifyMessage]]:
    _buffer = bytearray(b'\xc0T\xa9\x05')
    _buffer += struct.pack('<i', max_id)
    return Request(b'' + _buffer)
def set_typing(*, peer: abcs.InputPeer, top_msg_id: Optional[int], action: abcs.SendMessageAction) -> Request[bool]:
    _buffer = bytearray(b'\xe2>\x94X')
    flags = (0 if top_msg_id is None else 1)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    if top_msg_id is not None:
      _buffer += struct.pack(f'<i', top_msg_id)
    action._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def send_message(*, no_webpage: bool, silent: bool, background: bool, clear_draft: bool, noforwards: bool, update_stickersets_order: bool, peer: abcs.InputPeer, reply_to: Optional[abcs.InputReplyTo], message: str, random_id: int, reply_markup: Optional[abcs.ReplyMarkup], entities: Optional[Sequence[abcs.MessageEntity]], schedule_date: Optional[int], send_as: Optional[abcs.InputPeer]) -> Request[abcs.Updates]:
    _buffer = bytearray(b'o\t\r(')
    flags = (2 if no_webpage else 0) | (32 if silent else 0) | (64 if background else 0) | (128 if clear_draft else 0) | (16384 if noforwards else 0) | (32768 if update_stickersets_order else 0) | (0 if reply_to is None else 1) | (0 if reply_markup is None else 4) | (0 if entities is None else 8) | (0 if schedule_date is None else 1024) | (0 if send_as is None else 8192)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    if reply_to is not None:
      reply_to._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, message.encode('utf-8'))
    _buffer += struct.pack('<q', random_id)
    if reply_markup is not None:
      reply_markup._write_boxed_to(_buffer)
    if entities is not None:
      _buffer += struct.pack('<ii', 0x1cb5c415, len(entities))
      for _t0 in entities:
        _t0._write_boxed_to(_buffer)
    if schedule_date is not None:
      _buffer += struct.pack(f'<i', schedule_date)
    if send_as is not None:
      send_as._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def send_media(*, silent: bool, background: bool, clear_draft: bool, noforwards: bool, update_stickersets_order: bool, peer: abcs.InputPeer, reply_to: Optional[abcs.InputReplyTo], media: abcs.InputMedia, message: str, random_id: int, reply_markup: Optional[abcs.ReplyMarkup], entities: Optional[Sequence[abcs.MessageEntity]], schedule_date: Optional[int], send_as: Optional[abcs.InputPeer]) -> Request[abcs.Updates]:
    _buffer = bytearray(b'=\xc2\xccr')
    flags = (32 if silent else 0) | (64 if background else 0) | (128 if clear_draft else 0) | (16384 if noforwards else 0) | (32768 if update_stickersets_order else 0) | (0 if reply_to is None else 1) | (0 if reply_markup is None else 4) | (0 if entities is None else 8) | (0 if schedule_date is None else 1024) | (0 if send_as is None else 8192)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    if reply_to is not None:
      reply_to._write_boxed_to(_buffer)
    media._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, message.encode('utf-8'))
    _buffer += struct.pack('<q', random_id)
    if reply_markup is not None:
      reply_markup._write_boxed_to(_buffer)
    if entities is not None:
      _buffer += struct.pack('<ii', 0x1cb5c415, len(entities))
      for _t0 in entities:
        _t0._write_boxed_to(_buffer)
    if schedule_date is not None:
      _buffer += struct.pack(f'<i', schedule_date)
    if send_as is not None:
      send_as._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def forward_messages(*, silent: bool, background: bool, with_my_score: bool, drop_author: bool, drop_media_captions: bool, noforwards: bool, from_peer: abcs.InputPeer, id: Sequence[int], random_id: Sequence[int], to_peer: abcs.InputPeer, top_msg_id: Optional[int], schedule_date: Optional[int], send_as: Optional[abcs.InputPeer]) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\xc4\xbba\xc6')
    flags = (32 if silent else 0) | (64 if background else 0) | (256 if with_my_score else 0) | (2048 if drop_author else 0) | (4096 if drop_media_captions else 0) | (16384 if noforwards else 0) | (0 if top_msg_id is None else 512) | (0 if schedule_date is None else 1024) | (0 if send_as is None else 8192)
    _buffer += struct.pack('<I', flags)
    from_peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<ii', 0x1cb5c415, len(id))
    _buffer += struct.pack(f'<{len(id)}i', *id)
    _buffer += struct.pack('<ii', 0x1cb5c415, len(random_id))
    _buffer += struct.pack(f'<{len(random_id)}q', *random_id)
    to_peer._write_boxed_to(_buffer)
    if top_msg_id is not None:
      _buffer += struct.pack(f'<i', top_msg_id)
    if schedule_date is not None:
      _buffer += struct.pack(f'<i', schedule_date)
    if send_as is not None:
      send_as._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def report_spam(*, peer: abcs.InputPeer) -> Request[bool]:
    _buffer = bytearray(b'\xdb\x92\x15\xcf')
    peer._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_peer_settings(*, peer: abcs.InputPeer) -> Request[abcs.messages.PeerSettings]:
    _buffer = bytearray(b'\xa2\xa6\xd9\xef')
    peer._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def report(*, peer: abcs.InputPeer, id: Sequence[int], reason: abcs.ReportReason, message: str) -> Request[bool]:
    _buffer = bytearray(b'N\xabS\x89')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<ii', 0x1cb5c415, len(id))
    _buffer += struct.pack(f'<{len(id)}i', *id)
    reason._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, message.encode('utf-8'))
    return Request(b'' + _buffer)
def get_chats(*, id: Sequence[int]) -> Request[abcs.messages.Chats]:
    _buffer = bytearray(b'\x8fR\xe9I')
    _buffer += struct.pack('<ii', 0x1cb5c415, len(id))
    _buffer += struct.pack(f'<{len(id)}q', *id)
    return Request(b'' + _buffer)
def get_full_chat(*, chat_id: int) -> Request[abcs.messages.ChatFull]:
    _buffer = bytearray(b'4\x0b\xb0\xae')
    _buffer += struct.pack('<q', chat_id)
    return Request(b'' + _buffer)
def edit_chat_title(*, chat_id: int, title: str) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\xfd?xs')
    _buffer += struct.pack('<q', chat_id)
    serialize_bytes_to(_buffer, title.encode('utf-8'))
    return Request(b'' + _buffer)
def edit_chat_photo(*, chat_id: int, photo: abcs.InputChatPhoto) -> Request[abcs.Updates]:
    _buffer = bytearray(b't\xd6\xdd5')
    _buffer += struct.pack('<q', chat_id)
    photo._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def add_chat_user(*, chat_id: int, user_id: abcs.InputUser, fwd_limit: int) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\xe3SG\xf2')
    _buffer += struct.pack('<q', chat_id)
    user_id._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', fwd_limit)
    return Request(b'' + _buffer)
def delete_chat_user(*, revoke_history: bool, chat_id: int, user_id: abcs.InputUser) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\xab\\\x18\xa2')
    flags = (1 if revoke_history else 0)
    _buffer += struct.pack('<I', flags)
    _buffer += struct.pack('<q', chat_id)
    user_id._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def create_chat(*, users: Sequence[abcs.InputUser], title: str, ttl_period: Optional[int]) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\x18\xa84\x00')
    flags = (0 if ttl_period is None else 1)
    _buffer += struct.pack('<I', flags)
    _buffer += struct.pack('<ii', 0x1cb5c415, len(users))
    for _t0 in users:
      _t0._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, title.encode('utf-8'))
    if ttl_period is not None:
      _buffer += struct.pack(f'<i', ttl_period)
    return Request(b'' + _buffer)
def get_dh_config(*, version: int, random_length: int) -> Request[abcs.messages.DhConfig]:
    _buffer = bytearray(b'P\x89\xcf&')
    _buffer += struct.pack('<ii', version, random_length)
    return Request(b'' + _buffer)
def request_encryption(*, user_id: abcs.InputUser, random_id: int, g_a: _bytes) -> Request[abcs.EncryptedChat]:
    _buffer = bytearray(b'C\xafM\xf6')
    user_id._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', random_id)
    serialize_bytes_to(_buffer, g_a)
    return Request(b'' + _buffer)
def accept_encryption(*, peer: abcs.InputEncryptedChat, g_b: _bytes, key_fingerprint: int) -> Request[abcs.EncryptedChat]:
    _buffer = bytearray(b'\x15\x04\xbc=')
    peer._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, g_b)
    _buffer += struct.pack('<q', key_fingerprint)
    return Request(b'' + _buffer)
def discard_encryption(*, delete_history: bool, chat_id: int) -> Request[bool]:
    _buffer = bytearray(b'\xa0\xae\x93\xf3')
    flags = (1 if delete_history else 0)
    _buffer += struct.pack('<I', flags)
    _buffer += struct.pack('<i', chat_id)
    return Request(b'' + _buffer)
def set_encrypted_typing(*, peer: abcs.InputEncryptedChat, typing: bool) -> Request[bool]:
    _buffer = bytearray(b'\xedQ\x14y')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<I', typing)
    return Request(b'' + _buffer)
def read_encrypted_history(*, peer: abcs.InputEncryptedChat, max_date: int) -> Request[bool]:
    _buffer = bytearray(b'\niK\x7f')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', max_date)
    return Request(b'' + _buffer)
def send_encrypted(*, silent: bool, peer: abcs.InputEncryptedChat, random_id: int, data: _bytes) -> Request[abcs.messages.SentEncryptedMessage]:
    _buffer = bytearray(b'\x15z\xfaD')
    flags = (1 if silent else 0)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<q', random_id)
    serialize_bytes_to(_buffer, data)
    return Request(b'' + _buffer)
def send_encrypted_file(*, silent: bool, peer: abcs.InputEncryptedChat, random_id: int, data: _bytes, file: abcs.InputEncryptedFile) -> Request[abcs.messages.SentEncryptedMessage]:
    _buffer = bytearray(b'\x1dHYU')
    flags = (1 if silent else 0)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<q', random_id)
    serialize_bytes_to(_buffer, data)
    file._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def send_encrypted_service(*, peer: abcs.InputEncryptedChat, random_id: int, data: _bytes) -> Request[abcs.messages.SentEncryptedMessage]:
    _buffer = bytearray(b'\xa49\xd42')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<q', random_id)
    serialize_bytes_to(_buffer, data)
    return Request(b'' + _buffer)
def received_queue(*, max_qts: int) -> Request[Sequence[int]]:
    _buffer = bytearray(b'f\xbb\xa5U')
    _buffer += struct.pack('<i', max_qts)
    return Request(b'' + _buffer)
def report_encrypted_spam(*, peer: abcs.InputEncryptedChat) -> Request[bool]:
    _buffer = bytearray(b'\x0f\x8c\x0cK')
    peer._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def read_message_contents(*, id: Sequence[int]) -> Request[abcs.messages.AffectedMessages]:
    _buffer = bytearray(b'w?\xa76')
    _buffer += struct.pack('<ii', 0x1cb5c415, len(id))
    _buffer += struct.pack(f'<{len(id)}i', *id)
    return Request(b'' + _buffer)
def get_stickers(*, emoticon: str, hash: int) -> Request[abcs.messages.Stickers]:
    _buffer = bytearray(b'\xa1\xd3\xa5\xd5')
    serialize_bytes_to(_buffer, emoticon.encode('utf-8'))
    _buffer += struct.pack('<q', hash)
    return Request(b'' + _buffer)
def get_all_stickers(*, hash: int) -> Request[abcs.messages.AllStickers]:
    _buffer = bytearray(b'\xa8\xa1\xa0\xb8')
    _buffer += struct.pack('<q', hash)
    return Request(b'' + _buffer)
def get_web_page_preview(*, message: str, entities: Optional[Sequence[abcs.MessageEntity]]) -> Request[abcs.MessageMedia]:
    _buffer = bytearray(b'\xcc\xb0h\x8b')
    flags = (0 if entities is None else 8)
    _buffer += struct.pack('<I', flags)
    serialize_bytes_to(_buffer, message.encode('utf-8'))
    if entities is not None:
      _buffer += struct.pack('<ii', 0x1cb5c415, len(entities))
      for _t0 in entities:
        _t0._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def export_chat_invite(*, legacy_revoke_permanent: bool, request_needed: bool, peer: abcs.InputPeer, expire_date: Optional[int], usage_limit: Optional[int], title: Optional[str]) -> Request[abcs.ExportedChatInvite]:
    _buffer = bytearray(b'\xd5\xe5,\xa0')
    flags = (4 if legacy_revoke_permanent else 0) | (8 if request_needed else 0) | (0 if expire_date is None else 1) | (0 if usage_limit is None else 2) | (0 if title is None else 16)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    if expire_date is not None:
      _buffer += struct.pack(f'<i', expire_date)
    if usage_limit is not None:
      _buffer += struct.pack(f'<i', usage_limit)
    if title is not None:
      serialize_bytes_to(_buffer, title.encode('utf-8'))
    return Request(b'' + _buffer)
def check_chat_invite(*, hash: str) -> Request[abcs.ChatInvite]:
    _buffer = bytearray(b'\xbb\xb1\xad>')
    serialize_bytes_to(_buffer, hash.encode('utf-8'))
    return Request(b'' + _buffer)
def import_chat_invite(*, hash: str) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\x1c\x05Pl')
    serialize_bytes_to(_buffer, hash.encode('utf-8'))
    return Request(b'' + _buffer)
def get_sticker_set(*, stickerset: abcs.InputStickerSet, hash: int) -> Request[abcs.messages.StickerSet]:
    _buffer = bytearray(b't\xec\xa0\xc8')
    stickerset._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', hash)
    return Request(b'' + _buffer)
def install_sticker_set(*, stickerset: abcs.InputStickerSet, archived: bool) -> Request[abcs.messages.StickerSetInstallResult]:
    _buffer = bytearray(b'`\xe4\x8f\xc7')
    stickerset._write_boxed_to(_buffer)
    _buffer += struct.pack('<I', archived)
    return Request(b'' + _buffer)
def uninstall_sticker_set(*, stickerset: abcs.InputStickerSet) -> Request[bool]:
    _buffer = bytearray(b'\xdeUn\xf9')
    stickerset._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def start_bot(*, bot: abcs.InputUser, peer: abcs.InputPeer, random_id: int, start_param: str) -> Request[abcs.Updates]:
    _buffer = bytearray(b'xs\xdf\xe6')
    bot._write_boxed_to(_buffer)
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<q', random_id)
    serialize_bytes_to(_buffer, start_param.encode('utf-8'))
    return Request(b'' + _buffer)
def get_messages_views(*, peer: abcs.InputPeer, id: Sequence[int], increment: bool) -> Request[abcs.messages.MessageViews]:
    _buffer = bytearray(b'\xe1\xd3\x84W')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<ii', 0x1cb5c415, len(id))
    _buffer += struct.pack(f'<{len(id)}i', *id)
    _buffer += struct.pack('<I', increment)
    return Request(b'' + _buffer)
def edit_chat_admin(*, chat_id: int, user_id: abcs.InputUser, is_admin: bool) -> Request[bool]:
    _buffer = bytearray(b'\xc2\xd1[\xa8')
    _buffer += struct.pack('<q', chat_id)
    user_id._write_boxed_to(_buffer)
    _buffer += struct.pack('<I', is_admin)
    return Request(b'' + _buffer)
def migrate_chat(*, chat_id: int) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\x19S\x87\xa2')
    _buffer += struct.pack('<q', chat_id)
    return Request(b'' + _buffer)
def search_global(*, folder_id: Optional[int], q: str, filter: abcs.MessagesFilter, min_date: int, max_date: int, offset_rate: int, offset_peer: abcs.InputPeer, offset_id: int, limit: int) -> Request[abcs.messages.Messages]:
    _buffer = bytearray(b'\x9aX\xc6K')
    flags = (0 if folder_id is None else 1)
    _buffer += struct.pack('<I', flags)
    if folder_id is not None:
      _buffer += struct.pack(f'<i', folder_id)
    serialize_bytes_to(_buffer, q.encode('utf-8'))
    filter._write_boxed_to(_buffer)
    _buffer += struct.pack('<iii', min_date, max_date, offset_rate)
    offset_peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<ii', offset_id, limit)
    return Request(b'' + _buffer)
def reorder_sticker_sets(*, masks: bool, emojis: bool, order: Sequence[int]) -> Request[bool]:
    _buffer = bytearray(b'9w3x')
    flags = (1 if masks else 0) | (2 if emojis else 0)
    _buffer += struct.pack('<I', flags)
    _buffer += struct.pack('<ii', 0x1cb5c415, len(order))
    _buffer += struct.pack(f'<{len(order)}q', *order)
    return Request(b'' + _buffer)
def get_document_by_hash(*, sha256: _bytes, size: int, mime_type: str) -> Request[abcs.Document]:
    _buffer = bytearray(b'\x1f\x06\xf2\xb1')
    serialize_bytes_to(_buffer, sha256)
    _buffer += struct.pack('<q', size)
    serialize_bytes_to(_buffer, mime_type.encode('utf-8'))
    return Request(b'' + _buffer)
def get_saved_gifs(*, hash: int) -> Request[abcs.messages.SavedGifs]:
    _buffer = bytearray(b'5\x96\xf0\\')
    _buffer += struct.pack('<q', hash)
    return Request(b'' + _buffer)
def save_gif(*, id: abcs.InputDocument, unsave: bool) -> Request[bool]:
    _buffer = bytearray(b'\xcb0z2')
    id._write_boxed_to(_buffer)
    _buffer += struct.pack('<I', unsave)
    return Request(b'' + _buffer)
def get_inline_bot_results(*, bot: abcs.InputUser, peer: abcs.InputPeer, geo_point: Optional[abcs.InputGeoPoint], query: str, offset: str) -> Request[abcs.messages.BotResults]:
    _buffer = bytearray(b'\x9d\x99NQ')
    flags = (0 if geo_point is None else 1)
    _buffer += struct.pack('<I', flags)
    bot._write_boxed_to(_buffer)
    peer._write_boxed_to(_buffer)
    if geo_point is not None:
      geo_point._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, query.encode('utf-8'))
    serialize_bytes_to(_buffer, offset.encode('utf-8'))
    return Request(b'' + _buffer)
def set_inline_bot_results(*, gallery: bool, private: bool, query_id: int, results: Sequence[abcs.InputBotInlineResult], cache_time: int, next_offset: Optional[str], switch_pm: Optional[abcs.InlineBotSwitchPm], switch_webview: Optional[abcs.InlineBotWebView]) -> Request[bool]:
    _buffer = bytearray(b'\x19\xa4\x12\xbb')
    flags = (1 if gallery else 0) | (2 if private else 0) | (0 if next_offset is None else 4) | (0 if switch_pm is None else 8) | (0 if switch_webview is None else 16)
    _buffer += struct.pack('<I', flags)
    _buffer += struct.pack('<q', query_id)
    _buffer += struct.pack('<ii', 0x1cb5c415, len(results))
    for _t0 in results:
      _t0._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', cache_time)
    if next_offset is not None:
      serialize_bytes_to(_buffer, next_offset.encode('utf-8'))
    if switch_pm is not None:
      switch_pm._write_boxed_to(_buffer)
    if switch_webview is not None:
      switch_webview._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def send_inline_bot_result(*, silent: bool, background: bool, clear_draft: bool, hide_via: bool, peer: abcs.InputPeer, reply_to: Optional[abcs.InputReplyTo], random_id: int, query_id: int, id: str, schedule_date: Optional[int], send_as: Optional[abcs.InputPeer]) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\xbah\xbc\xf7')
    flags = (32 if silent else 0) | (64 if background else 0) | (128 if clear_draft else 0) | (2048 if hide_via else 0) | (0 if reply_to is None else 1) | (0 if schedule_date is None else 1024) | (0 if send_as is None else 8192)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    if reply_to is not None:
      reply_to._write_boxed_to(_buffer)
    _buffer += struct.pack('<qq', random_id, query_id)
    serialize_bytes_to(_buffer, id.encode('utf-8'))
    if schedule_date is not None:
      _buffer += struct.pack(f'<i', schedule_date)
    if send_as is not None:
      send_as._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_message_edit_data(*, peer: abcs.InputPeer, id: int) -> Request[abcs.messages.MessageEditData]:
    _buffer = bytearray(b'6\x8d\xa6\xfd')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', id)
    return Request(b'' + _buffer)
def edit_message(*, no_webpage: bool, peer: abcs.InputPeer, id: int, message: Optional[str], media: Optional[abcs.InputMedia], reply_markup: Optional[abcs.ReplyMarkup], entities: Optional[Sequence[abcs.MessageEntity]], schedule_date: Optional[int]) -> Request[abcs.Updates]:
    _buffer = bytearray(b'x\x17\xf7H')
    flags = (2 if no_webpage else 0) | (0 if message is None else 2048) | (0 if media is None else 16384) | (0 if reply_markup is None else 4) | (0 if entities is None else 8) | (0 if schedule_date is None else 32768)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', id)
    if message is not None:
      serialize_bytes_to(_buffer, message.encode('utf-8'))
    if media is not None:
      media._write_boxed_to(_buffer)
    if reply_markup is not None:
      reply_markup._write_boxed_to(_buffer)
    if entities is not None:
      _buffer += struct.pack('<ii', 0x1cb5c415, len(entities))
      for _t0 in entities:
        _t0._write_boxed_to(_buffer)
    if schedule_date is not None:
      _buffer += struct.pack(f'<i', schedule_date)
    return Request(b'' + _buffer)
def edit_inline_bot_message(*, no_webpage: bool, id: abcs.InputBotInlineMessageId, message: Optional[str], media: Optional[abcs.InputMedia], reply_markup: Optional[abcs.ReplyMarkup], entities: Optional[Sequence[abcs.MessageEntity]]) -> Request[bool]:
    _buffer = bytearray(b'\xba}U\x83')
    flags = (2 if no_webpage else 0) | (0 if message is None else 2048) | (0 if media is None else 16384) | (0 if reply_markup is None else 4) | (0 if entities is None else 8)
    _buffer += struct.pack('<I', flags)
    id._write_boxed_to(_buffer)
    if message is not None:
      serialize_bytes_to(_buffer, message.encode('utf-8'))
    if media is not None:
      media._write_boxed_to(_buffer)
    if reply_markup is not None:
      reply_markup._write_boxed_to(_buffer)
    if entities is not None:
      _buffer += struct.pack('<ii', 0x1cb5c415, len(entities))
      for _t0 in entities:
        _t0._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_bot_callback_answer(*, game: bool, peer: abcs.InputPeer, msg_id: int, data: Optional[_bytes], password: Optional[abcs.InputCheckPasswordSrp]) -> Request[abcs.messages.BotCallbackAnswer]:
    _buffer = bytearray(b'\x07\xcaB\x93')
    flags = (2 if game else 0) | (0 if data is None else 1) | (0 if password is None else 4)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', msg_id)
    if data is not None:
      serialize_bytes_to(_buffer, data)
    if password is not None:
      password._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def set_bot_callback_answer(*, alert: bool, query_id: int, message: Optional[str], url: Optional[str], cache_time: int) -> Request[bool]:
    _buffer = bytearray(b'\n\x13\x8f\xd5')
    flags = (2 if alert else 0) | (0 if message is None else 1) | (0 if url is None else 4)
    _buffer += struct.pack('<I', flags)
    _buffer += struct.pack('<q', query_id)
    if message is not None:
      serialize_bytes_to(_buffer, message.encode('utf-8'))
    if url is not None:
      serialize_bytes_to(_buffer, url.encode('utf-8'))
    _buffer += struct.pack('<i', cache_time)
    return Request(b'' + _buffer)
def get_peer_dialogs(*, peers: Sequence[abcs.InputDialogPeer]) -> Request[abcs.messages.PeerDialogs]:
    _buffer = bytearray(b'\xfd\xbcp\xe4')
    _buffer += struct.pack('<ii', 0x1cb5c415, len(peers))
    for _t0 in peers:
      _t0._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def save_draft(*, no_webpage: bool, reply_to_msg_id: Optional[int], top_msg_id: Optional[int], peer: abcs.InputPeer, message: str, entities: Optional[Sequence[abcs.MessageEntity]]) -> Request[bool]:
    _buffer = bytearray(b'?\x1e3\xb4')
    flags = (2 if no_webpage else 0) | (0 if reply_to_msg_id is None else 1) | (0 if top_msg_id is None else 4) | (0 if entities is None else 8)
    _buffer += struct.pack('<I', flags)
    if reply_to_msg_id is not None:
      _buffer += struct.pack(f'<i', reply_to_msg_id)
    if top_msg_id is not None:
      _buffer += struct.pack(f'<i', top_msg_id)
    peer._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, message.encode('utf-8'))
    if entities is not None:
      _buffer += struct.pack('<ii', 0x1cb5c415, len(entities))
      for _t0 in entities:
        _t0._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_all_drafts() -> Request[abcs.Updates]:
    _buffer = bytearray(b'e\x8d?j')
    return Request(b'' + _buffer)
def get_featured_stickers(*, hash: int) -> Request[abcs.messages.FeaturedStickers]:
    _buffer = bytearray(b'\x14\x0bxd')
    _buffer += struct.pack('<q', hash)
    return Request(b'' + _buffer)
def read_featured_stickers(*, id: Sequence[int]) -> Request[bool]:
    _buffer = bytearray(b'&\x81\x11[')
    _buffer += struct.pack('<ii', 0x1cb5c415, len(id))
    _buffer += struct.pack(f'<{len(id)}q', *id)
    return Request(b'' + _buffer)
def get_recent_stickers(*, attached: bool, hash: int) -> Request[abcs.messages.RecentStickers]:
    _buffer = bytearray(b';@\xa9\x9d')
    flags = (1 if attached else 0)
    _buffer += struct.pack('<I', flags)
    _buffer += struct.pack('<q', hash)
    return Request(b'' + _buffer)
def save_recent_sticker(*, attached: bool, id: abcs.InputDocument, unsave: bool) -> Request[bool]:
    _buffer = bytearray(b"\xf8\x18'9")
    flags = (1 if attached else 0)
    _buffer += struct.pack('<I', flags)
    id._write_boxed_to(_buffer)
    _buffer += struct.pack('<I', unsave)
    return Request(b'' + _buffer)
def clear_recent_stickers(*, attached: bool) -> Request[bool]:
    _buffer = bytearray(b'-`\x99\x89')
    flags = (1 if attached else 0)
    _buffer += struct.pack('<I', flags)
    return Request(b'' + _buffer)
def get_archived_stickers(*, masks: bool, emojis: bool, offset_id: int, limit: int) -> Request[abcs.messages.ArchivedStickers]:
    _buffer = bytearray(b'\x92v\xf1W')
    flags = (1 if masks else 0) | (2 if emojis else 0)
    _buffer += struct.pack('<I', flags)
    _buffer += struct.pack('<qi', offset_id, limit)
    return Request(b'' + _buffer)
def get_mask_stickers(*, hash: int) -> Request[abcs.messages.AllStickers]:
    _buffer = bytearray(b'\xb8\x82\x0fd')
    _buffer += struct.pack('<q', hash)
    return Request(b'' + _buffer)
def get_attached_stickers(*, media: abcs.InputStickeredMedia) -> Request[Sequence[abcs.StickerSetCovered]]:
    _buffer = bytearray(b'\xccg[\xcc')
    media._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def set_game_score(*, edit_message: bool, force: bool, peer: abcs.InputPeer, id: int, user_id: abcs.InputUser, score: int) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\xc0\xec\xf8\x8e')
    flags = (1 if edit_message else 0) | (2 if force else 0)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', id)
    user_id._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', score)
    return Request(b'' + _buffer)
def set_inline_game_score(*, edit_message: bool, force: bool, id: abcs.InputBotInlineMessageId, user_id: abcs.InputUser, score: int) -> Request[bool]:
    _buffer = bytearray(b'd\x9f\xad\x15')
    flags = (1 if edit_message else 0) | (2 if force else 0)
    _buffer += struct.pack('<I', flags)
    id._write_boxed_to(_buffer)
    user_id._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', score)
    return Request(b'' + _buffer)
def get_game_high_scores(*, peer: abcs.InputPeer, id: int, user_id: abcs.InputUser) -> Request[abcs.messages.HighScores]:
    _buffer = bytearray(b'\x9dd"\xe8')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', id)
    user_id._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_inline_game_high_scores(*, id: abcs.InputBotInlineMessageId, user_id: abcs.InputUser) -> Request[abcs.messages.HighScores]:
    _buffer = bytearray(b'\x1b^c\x0f')
    id._write_boxed_to(_buffer)
    user_id._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_common_chats(*, user_id: abcs.InputUser, max_id: int, limit: int) -> Request[abcs.messages.Chats]:
    _buffer = bytearray(b'\x04\xa1\x0c\xe4')
    user_id._write_boxed_to(_buffer)
    _buffer += struct.pack('<qi', max_id, limit)
    return Request(b'' + _buffer)
def get_web_page(*, url: str, hash: int) -> Request[abcs.messages.WebPage]:
    _buffer = bytearray(b'\xa3\x92\x96\x8d')
    serialize_bytes_to(_buffer, url.encode('utf-8'))
    _buffer += struct.pack('<i', hash)
    return Request(b'' + _buffer)
def toggle_dialog_pin(*, pinned: bool, peer: abcs.InputDialogPeer) -> Request[bool]:
    _buffer = bytearray(b'W\xe21\xa7')
    flags = (1 if pinned else 0)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def reorder_pinned_dialogs(*, force: bool, folder_id: int, order: Sequence[abcs.InputDialogPeer]) -> Request[bool]:
    _buffer = bytearray(b'7\xdf\x1a;')
    flags = (1 if force else 0)
    _buffer += struct.pack('<I', flags)
    _buffer += struct.pack('<i', folder_id)
    _buffer += struct.pack('<ii', 0x1cb5c415, len(order))
    for _t0 in order:
      _t0._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_pinned_dialogs(*, folder_id: int) -> Request[abcs.messages.PeerDialogs]:
    _buffer = bytearray(b'\xf2M\xb9\xd6')
    _buffer += struct.pack('<i', folder_id)
    return Request(b'' + _buffer)
def set_bot_shipping_results(*, query_id: int, error: Optional[str], shipping_options: Optional[Sequence[abcs.ShippingOption]]) -> Request[bool]:
    _buffer = bytearray(b'\xfar\xf6\xe5')
    flags = (0 if error is None else 1) | (0 if shipping_options is None else 2)
    _buffer += struct.pack('<Iq', flags, query_id)
    if error is not None:
      serialize_bytes_to(_buffer, error.encode('utf-8'))
    if shipping_options is not None:
      _buffer += struct.pack('<ii', 0x1cb5c415, len(shipping_options))
      for _t0 in shipping_options:
        _t0._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def set_bot_precheckout_results(*, success: bool, query_id: int, error: Optional[str]) -> Request[bool]:
    _buffer = bytearray(b'\x95\xdd\xc2\t')
    flags = (2 if success else 0) | (0 if error is None else 1)
    _buffer += struct.pack('<I', flags)
    _buffer += struct.pack('<q', query_id)
    if error is not None:
      serialize_bytes_to(_buffer, error.encode('utf-8'))
    return Request(b'' + _buffer)
def upload_media(*, peer: abcs.InputPeer, media: abcs.InputMedia) -> Request[abcs.MessageMedia]:
    _buffer = bytearray(b'\xb1\xc2\x9bQ')
    peer._write_boxed_to(_buffer)
    media._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def send_screenshot_notification(*, peer: abcs.InputPeer, reply_to: abcs.InputReplyTo, random_id: int) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\x17X@\xa1')
    peer._write_boxed_to(_buffer)
    reply_to._write_boxed_to(_buffer)
    _buffer += struct.pack('<q', random_id)
    return Request(b'' + _buffer)
def get_faved_stickers(*, hash: int) -> Request[abcs.messages.FavedStickers]:
    _buffer = bytearray(b'\xa9\xaa\xf1\x04')
    _buffer += struct.pack('<q', hash)
    return Request(b'' + _buffer)
def fave_sticker(*, id: abcs.InputDocument, unfave: bool) -> Request[bool]:
    _buffer = bytearray(b'[\xc5\xff\xb9')
    id._write_boxed_to(_buffer)
    _buffer += struct.pack('<I', unfave)
    return Request(b'' + _buffer)
def get_unread_mentions(*, peer: abcs.InputPeer, top_msg_id: Optional[int], offset_id: int, add_offset: int, limit: int, max_id: int, min_id: int) -> Request[abcs.messages.Messages]:
    _buffer = bytearray(b'\x90\xe7\x07\xf1')
    flags = (0 if top_msg_id is None else 1)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    if top_msg_id is not None:
      _buffer += struct.pack(f'<i', top_msg_id)
    _buffer += struct.pack('<iiiii', offset_id, add_offset, limit, max_id, min_id)
    return Request(b'' + _buffer)
def read_mentions(*, peer: abcs.InputPeer, top_msg_id: Optional[int]) -> Request[abcs.messages.AffectedHistory]:
    _buffer = bytearray(b'M\xbf\xe56')
    flags = (0 if top_msg_id is None else 1)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    if top_msg_id is not None:
      _buffer += struct.pack(f'<i', top_msg_id)
    return Request(b'' + _buffer)
def get_recent_locations(*, peer: abcs.InputPeer, limit: int, hash: int) -> Request[abcs.messages.Messages]:
    _buffer = bytearray(b'\xe0@*p')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<iq', limit, hash)
    return Request(b'' + _buffer)
def send_multi_media(*, silent: bool, background: bool, clear_draft: bool, noforwards: bool, update_stickersets_order: bool, peer: abcs.InputPeer, reply_to: Optional[abcs.InputReplyTo], multi_media: Sequence[abcs.InputSingleMedia], schedule_date: Optional[int], send_as: Optional[abcs.InputPeer]) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\x87\x89nE')
    flags = (32 if silent else 0) | (64 if background else 0) | (128 if clear_draft else 0) | (16384 if noforwards else 0) | (32768 if update_stickersets_order else 0) | (0 if reply_to is None else 1) | (0 if schedule_date is None else 1024) | (0 if send_as is None else 8192)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    if reply_to is not None:
      reply_to._write_boxed_to(_buffer)
    _buffer += struct.pack('<ii', 0x1cb5c415, len(multi_media))
    for _t0 in multi_media:
      _t0._write_boxed_to(_buffer)
    if schedule_date is not None:
      _buffer += struct.pack(f'<i', schedule_date)
    if send_as is not None:
      send_as._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def upload_encrypted_file(*, peer: abcs.InputEncryptedChat, file: abcs.InputEncryptedFile) -> Request[abcs.EncryptedFile]:
    _buffer = bytearray(b'\x97\xc4WP')
    peer._write_boxed_to(_buffer)
    file._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def search_sticker_sets(*, exclude_featured: bool, q: str, hash: int) -> Request[abcs.messages.FoundStickerSets]:
    _buffer = bytearray(b'\x8a[p5')
    flags = (1 if exclude_featured else 0)
    _buffer += struct.pack('<I', flags)
    serialize_bytes_to(_buffer, q.encode('utf-8'))
    _buffer += struct.pack('<q', hash)
    return Request(b'' + _buffer)
def get_split_ranges() -> Request[Sequence[abcs.MessageRange]]:
    _buffer = bytearray(b'\x08~\xff\x1c')
    return Request(b'' + _buffer)
def mark_dialog_unread(*, unread: bool, peer: abcs.InputDialogPeer) -> Request[bool]:
    _buffer = bytearray(b'\x8f\xd9\x86\xc2')
    flags = (1 if unread else 0)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_dialog_unread_marks() -> Request[Sequence[abcs.DialogPeer]]:
    _buffer = bytearray(b'"N\xe2"')
    return Request(b'' + _buffer)
def clear_all_drafts() -> Request[bool]:
    _buffer = bytearray(b'\x9c\xeeX~')
    return Request(b'' + _buffer)
def update_pinned_message(*, silent: bool, unpin: bool, pm_oneside: bool, peer: abcs.InputPeer, id: int) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\xec\xf7\xaa\xd2')
    flags = (1 if silent else 0) | (2 if unpin else 0) | (4 if pm_oneside else 0)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', id)
    return Request(b'' + _buffer)
def send_vote(*, peer: abcs.InputPeer, msg_id: int, options: Sequence[_bytes]) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\x84a\xea\x10')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', msg_id)
    _buffer += struct.pack('<ii', 0x1cb5c415, len(options))
    for _t0 in options:
      serialize_bytes_to(_buffer, _t0)
    return Request(b'' + _buffer)
def get_poll_results(*, peer: abcs.InputPeer, msg_id: int) -> Request[abcs.Updates]:
    _buffer = bytearray(b';d\xbbs')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', msg_id)
    return Request(b'' + _buffer)
def get_onlines(*, peer: abcs.InputPeer) -> Request[abcs.ChatOnlines]:
    _buffer = bytearray(b'P\xe0+n')
    peer._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def edit_chat_about(*, peer: abcs.InputPeer, about: str) -> Request[bool]:
    _buffer = bytearray(b'\x97\x07\xf6\xde')
    peer._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, about.encode('utf-8'))
    return Request(b'' + _buffer)
def edit_chat_default_banned_rights(*, peer: abcs.InputPeer, banned_rights: abcs.ChatBannedRights) -> Request[abcs.Updates]:
    _buffer = bytearray(b'Ak\x86\xa5')
    peer._write_boxed_to(_buffer)
    banned_rights._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_emoji_keywords(*, lang_code: str) -> Request[abcs.EmojiKeywordsDifference]:
    _buffer = bytearray(b'b\xe0\xa05')
    serialize_bytes_to(_buffer, lang_code.encode('utf-8'))
    return Request(b'' + _buffer)
def get_emoji_keywords_difference(*, lang_code: str, from_version: int) -> Request[abcs.EmojiKeywordsDifference]:
    _buffer = bytearray(b'\xaf\xb6\x08\x15')
    serialize_bytes_to(_buffer, lang_code.encode('utf-8'))
    _buffer += struct.pack('<i', from_version)
    return Request(b'' + _buffer)
def get_emoji_keywords_languages(*, lang_codes: Sequence[str]) -> Request[Sequence[abcs.EmojiLanguage]]:
    _buffer = bytearray(b'\xb2c\x99N')
    _buffer += struct.pack('<ii', 0x1cb5c415, len(lang_codes))
    for _t0 in lang_codes:
      serialize_bytes_to(_buffer, _t0.encode('utf-8'))
    return Request(b'' + _buffer)
def get_emoji_url(*, lang_code: str) -> Request[abcs.EmojiUrl]:
    _buffer = bytearray(b'&\x0c\xb1\xd5')
    serialize_bytes_to(_buffer, lang_code.encode('utf-8'))
    return Request(b'' + _buffer)
def get_search_counters(*, peer: abcs.InputPeer, top_msg_id: Optional[int], filters: Sequence[abcs.MessagesFilter]) -> Request[Sequence[abcs.messages.SearchCounter]]:
    _buffer = bytearray(b'\xc1|\xae\x00')
    flags = (0 if top_msg_id is None else 1)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    if top_msg_id is not None:
      _buffer += struct.pack(f'<i', top_msg_id)
    _buffer += struct.pack('<ii', 0x1cb5c415, len(filters))
    for _t0 in filters:
      _t0._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def request_url_auth(*, peer: Optional[abcs.InputPeer], msg_id: Optional[int], button_id: Optional[int], url: Optional[str]) -> Request[abcs.UrlAuthResult]:
    _buffer = bytearray(b'F\xb4\x8f\x19')
    flags = (0 if peer is None else 2) | (0 if msg_id is None else 2) | (0 if button_id is None else 2) | (0 if url is None else 4)
    _buffer += struct.pack('<I', flags)
    if peer is not None:
      peer._write_boxed_to(_buffer)
    if msg_id is not None:
      _buffer += struct.pack(f'<i', msg_id)
    if button_id is not None:
      _buffer += struct.pack(f'<i', button_id)
    if url is not None:
      serialize_bytes_to(_buffer, url.encode('utf-8'))
    return Request(b'' + _buffer)
def accept_url_auth(*, write_allowed: bool, peer: Optional[abcs.InputPeer], msg_id: Optional[int], button_id: Optional[int], url: Optional[str]) -> Request[abcs.UrlAuthResult]:
    _buffer = bytearray(b'%q,\xb1')
    flags = (1 if write_allowed else 0) | (0 if peer is None else 2) | (0 if msg_id is None else 2) | (0 if button_id is None else 2) | (0 if url is None else 4)
    _buffer += struct.pack('<I', flags)
    if peer is not None:
      peer._write_boxed_to(_buffer)
    if msg_id is not None:
      _buffer += struct.pack(f'<i', msg_id)
    if button_id is not None:
      _buffer += struct.pack(f'<i', button_id)
    if url is not None:
      serialize_bytes_to(_buffer, url.encode('utf-8'))
    return Request(b'' + _buffer)
def hide_peer_settings_bar(*, peer: abcs.InputPeer) -> Request[bool]:
    _buffer = bytearray(b'8\xb1\xacO')
    peer._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_scheduled_history(*, peer: abcs.InputPeer, hash: int) -> Request[abcs.messages.Messages]:
    _buffer = bytearray(b'\x0bv\x16\xf5')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<q', hash)
    return Request(b'' + _buffer)
def get_scheduled_messages(*, peer: abcs.InputPeer, id: Sequence[int]) -> Request[abcs.messages.Messages]:
    _buffer = bytearray(b'd\x04\xbb\xbd')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<ii', 0x1cb5c415, len(id))
    _buffer += struct.pack(f'<{len(id)}i', *id)
    return Request(b'' + _buffer)
def send_scheduled_messages(*, peer: abcs.InputPeer, id: Sequence[int]) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\n\x858\xbd')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<ii', 0x1cb5c415, len(id))
    _buffer += struct.pack(f'<{len(id)}i', *id)
    return Request(b'' + _buffer)
def delete_scheduled_messages(*, peer: abcs.InputPeer, id: Sequence[int]) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\x16+\xaeY')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<ii', 0x1cb5c415, len(id))
    _buffer += struct.pack(f'<{len(id)}i', *id)
    return Request(b'' + _buffer)
def get_poll_votes(*, peer: abcs.InputPeer, id: int, option: Optional[_bytes], offset: Optional[str], limit: int) -> Request[abcs.messages.VotesList]:
    _buffer = bytearray(b'\x0e8n\xb8')
    flags = (0 if option is None else 1) | (0 if offset is None else 2)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', id)
    if option is not None:
      serialize_bytes_to(_buffer, option)
    if offset is not None:
      serialize_bytes_to(_buffer, offset.encode('utf-8'))
    _buffer += struct.pack('<i', limit)
    return Request(b'' + _buffer)
def toggle_sticker_sets(*, uninstall: bool, archive: bool, unarchive: bool, stickersets: Sequence[abcs.InputStickerSet]) -> Request[bool]:
    _buffer = bytearray(b'\xea/\x05\xb5')
    flags = (1 if uninstall else 0) | (2 if archive else 0) | (4 if unarchive else 0)
    _buffer += struct.pack('<I', flags)
    _buffer += struct.pack('<ii', 0x1cb5c415, len(stickersets))
    for _t0 in stickersets:
      _t0._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_dialog_filters() -> Request[Sequence[abcs.DialogFilter]]:
    _buffer = bytearray(b'm\xd9\x9e\xf1')
    return Request(b'' + _buffer)
def get_suggested_dialog_filters() -> Request[Sequence[abcs.DialogFilterSuggested]]:
    _buffer = bytearray(b',\xd4\x9c\xa2')
    return Request(b'' + _buffer)
def update_dialog_filter(*, id: int, filter: Optional[abcs.DialogFilter]) -> Request[bool]:
    _buffer = bytearray(b'J\xa0\xd4\x1a')
    flags = (0 if filter is None else 1)
    _buffer += struct.pack('<Ii', flags, id)
    if filter is not None:
      filter._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def update_dialog_filters_order(*, order: Sequence[int]) -> Request[bool]:
    _buffer = bytearray(b'\xe4\xc1c\xc5')
    _buffer += struct.pack('<ii', 0x1cb5c415, len(order))
    _buffer += struct.pack(f'<{len(order)}i', *order)
    return Request(b'' + _buffer)
def get_old_featured_stickers(*, offset: int, limit: int, hash: int) -> Request[abcs.messages.FeaturedStickers]:
    _buffer = bytearray(b'\xa1\x94\xd0~')
    _buffer += struct.pack('<iiq', offset, limit, hash)
    return Request(b'' + _buffer)
def get_replies(*, peer: abcs.InputPeer, msg_id: int, offset_id: int, offset_date: int, add_offset: int, limit: int, max_id: int, min_id: int, hash: int) -> Request[abcs.messages.Messages]:
    _buffer = bytearray(b'\x0c\xd3\xdd"')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<iiiiiiiq', msg_id, offset_id, offset_date, add_offset, limit, max_id, min_id, hash)
    return Request(b'' + _buffer)
def get_discussion_message(*, peer: abcs.InputPeer, msg_id: int) -> Request[abcs.messages.DiscussionMessage]:
    _buffer = bytearray(b'\xfdriD')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', msg_id)
    return Request(b'' + _buffer)
def read_discussion(*, peer: abcs.InputPeer, msg_id: int, read_max_id: int) -> Request[bool]:
    _buffer = bytearray(b'\xf4\xa91\xf7')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<ii', msg_id, read_max_id)
    return Request(b'' + _buffer)
def unpin_all_messages(*, peer: abcs.InputPeer, top_msg_id: Optional[int]) -> Request[abcs.messages.AffectedHistory]:
    _buffer = bytearray(b'\xa8\xb9"\xee')
    flags = (0 if top_msg_id is None else 1)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    if top_msg_id is not None:
      _buffer += struct.pack(f'<i', top_msg_id)
    return Request(b'' + _buffer)
def delete_chat(*, chat_id: int) -> Request[bool]:
    _buffer = bytearray(b'P\xee\xd0[')
    _buffer += struct.pack('<q', chat_id)
    return Request(b'' + _buffer)
def delete_phone_call_history(*, revoke: bool) -> Request[abcs.messages.AffectedFoundMessages]:
    _buffer = bytearray(b'\t\xe4\xcb\xf9')
    flags = (1 if revoke else 0)
    _buffer += struct.pack('<I', flags)
    return Request(b'' + _buffer)
def check_history_import(*, import_head: str) -> Request[abcs.messages.HistoryImportParsed]:
    _buffer = bytearray(b'\xf3\x19\xfeC')
    serialize_bytes_to(_buffer, import_head.encode('utf-8'))
    return Request(b'' + _buffer)
def init_history_import(*, peer: abcs.InputPeer, file: abcs.InputFile, media_count: int) -> Request[abcs.messages.HistoryImport]:
    _buffer = bytearray(b';\x0c\t4')
    peer._write_boxed_to(_buffer)
    file._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', media_count)
    return Request(b'' + _buffer)
def upload_imported_media(*, peer: abcs.InputPeer, import_id: int, file_name: str, media: abcs.InputMedia) -> Request[abcs.MessageMedia]:
    _buffer = bytearray(b'\x92 \x86*')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<q', import_id)
    serialize_bytes_to(_buffer, file_name.encode('utf-8'))
    media._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def start_history_import(*, peer: abcs.InputPeer, import_id: int) -> Request[bool]:
    _buffer = bytearray(b'D\xf3=\xb4')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<q', import_id)
    return Request(b'' + _buffer)
def get_exported_chat_invites(*, revoked: bool, peer: abcs.InputPeer, admin_id: abcs.InputUser, offset_date: Optional[int], offset_link: Optional[str], limit: int) -> Request[abcs.messages.ExportedChatInvites]:
    _buffer = bytearray(b'\xf6\xa3\xb5\xa2')
    flags = (8 if revoked else 0) | (0 if offset_date is None else 4) | (0 if offset_link is None else 4)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    admin_id._write_boxed_to(_buffer)
    if offset_date is not None:
      _buffer += struct.pack(f'<i', offset_date)
    if offset_link is not None:
      serialize_bytes_to(_buffer, offset_link.encode('utf-8'))
    _buffer += struct.pack('<i', limit)
    return Request(b'' + _buffer)
def get_exported_chat_invite(*, peer: abcs.InputPeer, link: str) -> Request[abcs.messages.ExportedChatInvite]:
    _buffer = bytearray(b'\\ots')
    peer._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, link.encode('utf-8'))
    return Request(b'' + _buffer)
def edit_exported_chat_invite(*, revoked: bool, peer: abcs.InputPeer, link: str, expire_date: Optional[int], usage_limit: Optional[int], request_needed: Optional[bool], title: Optional[str]) -> Request[abcs.messages.ExportedChatInvite]:
    _buffer = bytearray(b'u/\xca\xbd')
    flags = (4 if revoked else 0) | (0 if expire_date is None else 1) | (0 if usage_limit is None else 2) | (0 if request_needed is None else 8) | (0 if title is None else 16)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, link.encode('utf-8'))
    if expire_date is not None:
      _buffer += struct.pack(f'<i', expire_date)
    if usage_limit is not None:
      _buffer += struct.pack(f'<i', usage_limit)
    if request_needed is not None:
      _buffer += struct.pack(f'<I', (0x997275b5 if request_needed else 0xbc799737))
    if title is not None:
      serialize_bytes_to(_buffer, title.encode('utf-8'))
    return Request(b'' + _buffer)
def delete_revoked_exported_chat_invites(*, peer: abcs.InputPeer, admin_id: abcs.InputUser) -> Request[bool]:
    _buffer = bytearray(b'\xd5{\x98V')
    peer._write_boxed_to(_buffer)
    admin_id._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def delete_exported_chat_invite(*, peer: abcs.InputPeer, link: str) -> Request[bool]:
    _buffer = bytearray(b'+\xa4d\xd4')
    peer._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, link.encode('utf-8'))
    return Request(b'' + _buffer)
def get_admins_with_invites(*, peer: abcs.InputPeer) -> Request[abcs.messages.ChatAdminsWithInvites]:
    _buffer = bytearray(b'\xef\xe6 9')
    peer._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_chat_invite_importers(*, requested: bool, peer: abcs.InputPeer, link: Optional[str], q: Optional[str], offset_date: int, offset_user: abcs.InputUser, limit: int) -> Request[abcs.messages.ChatInviteImporters]:
    _buffer = bytearray(b'N\xdd\x04\xdf')
    flags = (1 if requested else 0) | (0 if link is None else 2) | (0 if q is None else 4)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    if link is not None:
      serialize_bytes_to(_buffer, link.encode('utf-8'))
    if q is not None:
      serialize_bytes_to(_buffer, q.encode('utf-8'))
    _buffer += struct.pack('<i', offset_date)
    offset_user._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', limit)
    return Request(b'' + _buffer)
def set_history_ttl(*, peer: abcs.InputPeer, period: int) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\xe4_\x0e\xb8')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', period)
    return Request(b'' + _buffer)
def check_history_import_peer(*, peer: abcs.InputPeer) -> Request[abcs.messages.CheckedHistoryImportPeer]:
    _buffer = bytearray(b'\x03\x0f\xc6]')
    peer._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def set_chat_theme(*, peer: abcs.InputPeer, emoticon: str) -> Request[abcs.Updates]:
    _buffer = bytearray(b'?\xe1;\xe6')
    peer._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, emoticon.encode('utf-8'))
    return Request(b'' + _buffer)
def get_message_read_participants(*, peer: abcs.InputPeer, msg_id: int) -> Request[Sequence[abcs.ReadParticipantDate]]:
    _buffer = bytearray(b'O\xc4\xc11')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', msg_id)
    return Request(b'' + _buffer)
def get_search_results_calendar(*, peer: abcs.InputPeer, filter: abcs.MessagesFilter, offset_id: int, offset_date: int) -> Request[abcs.messages.SearchResultsCalendar]:
    _buffer = bytearray(b'\xe9\xbd\xf0I')
    peer._write_boxed_to(_buffer)
    filter._write_boxed_to(_buffer)
    _buffer += struct.pack('<ii', offset_id, offset_date)
    return Request(b'' + _buffer)
def get_search_results_positions(*, peer: abcs.InputPeer, filter: abcs.MessagesFilter, offset_id: int, limit: int) -> Request[abcs.messages.SearchResultsPositions]:
    _buffer = bytearray(b'\xa3\x83\x95n')
    peer._write_boxed_to(_buffer)
    filter._write_boxed_to(_buffer)
    _buffer += struct.pack('<ii', offset_id, limit)
    return Request(b'' + _buffer)
def hide_chat_join_request(*, approved: bool, peer: abcs.InputPeer, user_id: abcs.InputUser) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\x15\xe8\xe7\x7f')
    flags = (1 if approved else 0)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    user_id._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def hide_all_chat_join_requests(*, approved: bool, peer: abcs.InputPeer, link: Optional[str]) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\xea\xf4\x85\xe0')
    flags = (1 if approved else 0) | (0 if link is None else 2)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    if link is not None:
      serialize_bytes_to(_buffer, link.encode('utf-8'))
    return Request(b'' + _buffer)
def toggle_no_forwards(*, peer: abcs.InputPeer, enabled: bool) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\xa2\xaf\x1e\xb1')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<I', enabled)
    return Request(b'' + _buffer)
def save_default_send_as(*, peer: abcs.InputPeer, send_as: abcs.InputPeer) -> Request[bool]:
    _buffer = bytearray(b'\x96\xdf\xfd\xcc')
    peer._write_boxed_to(_buffer)
    send_as._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def send_reaction(*, big: bool, add_to_recent: bool, peer: abcs.InputPeer, msg_id: int, reaction: Optional[Sequence[abcs.Reaction]]) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\xd4x\r\xd3')
    flags = (2 if big else 0) | (4 if add_to_recent else 0) | (0 if reaction is None else 1)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', msg_id)
    if reaction is not None:
      _buffer += struct.pack('<ii', 0x1cb5c415, len(reaction))
      for _t0 in reaction:
        _t0._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_messages_reactions(*, peer: abcs.InputPeer, id: Sequence[int]) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\xe6\x90\xba\x8b')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<ii', 0x1cb5c415, len(id))
    _buffer += struct.pack(f'<{len(id)}i', *id)
    return Request(b'' + _buffer)
def get_message_reactions_list(*, peer: abcs.InputPeer, id: int, reaction: Optional[abcs.Reaction], offset: Optional[str], limit: int) -> Request[abcs.messages.MessageReactionsList]:
    _buffer = bytearray(b'H?\x1bF')
    flags = (0 if reaction is None else 1) | (0 if offset is None else 2)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', id)
    if reaction is not None:
      reaction._write_boxed_to(_buffer)
    if offset is not None:
      serialize_bytes_to(_buffer, offset.encode('utf-8'))
    _buffer += struct.pack('<i', limit)
    return Request(b'' + _buffer)
def set_chat_available_reactions(*, peer: abcs.InputPeer, available_reactions: abcs.ChatReactions) -> Request[abcs.Updates]:
    _buffer = bytearray(b'qg\xb1\xfe')
    peer._write_boxed_to(_buffer)
    available_reactions._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_available_reactions(*, hash: int) -> Request[abcs.messages.AvailableReactions]:
    _buffer = bytearray(b'\xac\xa0\xde\x18')
    _buffer += struct.pack('<i', hash)
    return Request(b'' + _buffer)
def set_default_reaction(*, reaction: abcs.Reaction) -> Request[bool]:
    _buffer = bytearray(b'\x16\xa0GO')
    reaction._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def translate_text(*, peer: Optional[abcs.InputPeer], id: Optional[Sequence[int]], text: Optional[Sequence[abcs.TextWithEntities]], to_lang: str) -> Request[abcs.messages.TranslatedText]:
    _buffer = bytearray(b'00\x18c')
    flags = (0 if peer is None else 1) | (0 if id is None else 1) | (0 if text is None else 2)
    _buffer += struct.pack('<I', flags)
    if peer is not None:
      peer._write_boxed_to(_buffer)
    if id is not None:
      _buffer += struct.pack('<ii', 0x1cb5c415, len(id))
      _buffer += struct.pack(f'<{len(id)}i', *id)
    if text is not None:
      _buffer += struct.pack('<ii', 0x1cb5c415, len(text))
      for _t0 in text:
        _t0._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, to_lang.encode('utf-8'))
    return Request(b'' + _buffer)
def get_unread_reactions(*, peer: abcs.InputPeer, top_msg_id: Optional[int], offset_id: int, add_offset: int, limit: int, max_id: int, min_id: int) -> Request[abcs.messages.Messages]:
    _buffer = bytearray(b'[I#2')
    flags = (0 if top_msg_id is None else 1)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    if top_msg_id is not None:
      _buffer += struct.pack(f'<i', top_msg_id)
    _buffer += struct.pack('<iiiii', offset_id, add_offset, limit, max_id, min_id)
    return Request(b'' + _buffer)
def read_reactions(*, peer: abcs.InputPeer, top_msg_id: Optional[int]) -> Request[abcs.messages.AffectedHistory]:
    _buffer = bytearray(b'\x8e\x7f\xaaT')
    flags = (0 if top_msg_id is None else 1)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    if top_msg_id is not None:
      _buffer += struct.pack(f'<i', top_msg_id)
    return Request(b'' + _buffer)
def search_sent_media(*, q: str, filter: abcs.MessagesFilter, limit: int) -> Request[abcs.messages.Messages]:
    _buffer = bytearray(b'\xa01~\x10')
    serialize_bytes_to(_buffer, q.encode('utf-8'))
    filter._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', limit)
    return Request(b'' + _buffer)
def get_attach_menu_bots(*, hash: int) -> Request[abcs.AttachMenuBots]:
    _buffer = bytearray(b'\xcb\xc2\xfc\x16')
    _buffer += struct.pack('<q', hash)
    return Request(b'' + _buffer)
def get_attach_menu_bot(*, bot: abcs.InputUser) -> Request[abcs.AttachMenuBotsBot]:
    _buffer = bytearray(b'\x92a!w')
    bot._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def toggle_bot_in_attach_menu(*, write_allowed: bool, bot: abcs.InputUser, enabled: bool) -> Request[bool]:
    _buffer = bytearray(b'i\x9d\xf5i')
    flags = (1 if write_allowed else 0)
    _buffer += struct.pack('<I', flags)
    bot._write_boxed_to(_buffer)
    _buffer += struct.pack('<I', enabled)
    return Request(b'' + _buffer)
def request_web_view(*, from_bot_menu: bool, silent: bool, peer: abcs.InputPeer, bot: abcs.InputUser, url: Optional[str], start_param: Optional[str], theme_params: Optional[abcs.DataJson], platform: str, reply_to: Optional[abcs.InputReplyTo], send_as: Optional[abcs.InputPeer]) -> Request[abcs.WebViewResult]:
    _buffer = bytearray(b'\xc1\xc2\x9d&')
    flags = (16 if from_bot_menu else 0) | (32 if silent else 0) | (0 if url is None else 2) | (0 if start_param is None else 8) | (0 if theme_params is None else 4) | (0 if reply_to is None else 1) | (0 if send_as is None else 8192)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    bot._write_boxed_to(_buffer)
    if url is not None:
      serialize_bytes_to(_buffer, url.encode('utf-8'))
    if start_param is not None:
      serialize_bytes_to(_buffer, start_param.encode('utf-8'))
    if theme_params is not None:
      theme_params._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, platform.encode('utf-8'))
    if reply_to is not None:
      reply_to._write_boxed_to(_buffer)
    if send_as is not None:
      send_as._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def prolong_web_view(*, silent: bool, peer: abcs.InputPeer, bot: abcs.InputUser, query_id: int, reply_to: Optional[abcs.InputReplyTo], send_as: Optional[abcs.InputPeer]) -> Request[bool]:
    _buffer = bytearray(b'\x83\x1a\xd8\xb0')
    flags = (32 if silent else 0) | (0 if reply_to is None else 1) | (0 if send_as is None else 8192)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    bot._write_boxed_to(_buffer)
    _buffer += struct.pack('<q', query_id)
    if reply_to is not None:
      reply_to._write_boxed_to(_buffer)
    if send_as is not None:
      send_as._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def request_simple_web_view(*, from_switch_webview: bool, from_side_menu: bool, bot: abcs.InputUser, url: Optional[str], start_param: Optional[str], theme_params: Optional[abcs.DataJson], platform: str) -> Request[abcs.SimpleWebViewResult]:
    _buffer = bytearray(b'\nPF\x1a')
    flags = (2 if from_switch_webview else 0) | (4 if from_side_menu else 0) | (0 if url is None else 8) | (0 if start_param is None else 16) | (0 if theme_params is None else 1)
    _buffer += struct.pack('<I', flags)
    bot._write_boxed_to(_buffer)
    if url is not None:
      serialize_bytes_to(_buffer, url.encode('utf-8'))
    if start_param is not None:
      serialize_bytes_to(_buffer, start_param.encode('utf-8'))
    if theme_params is not None:
      theme_params._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, platform.encode('utf-8'))
    return Request(b'' + _buffer)
def send_web_view_result_message(*, bot_query_id: str, result: abcs.InputBotInlineResult) -> Request[abcs.WebViewMessageSent]:
    _buffer = bytearray(b'\xf5\x14C\n')
    serialize_bytes_to(_buffer, bot_query_id.encode('utf-8'))
    result._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def send_web_view_data(*, bot: abcs.InputUser, random_id: int, button_text: str, data: str) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\xc8B\x02\xdc')
    bot._write_boxed_to(_buffer)
    _buffer += struct.pack('<q', random_id)
    serialize_bytes_to(_buffer, button_text.encode('utf-8'))
    serialize_bytes_to(_buffer, data.encode('utf-8'))
    return Request(b'' + _buffer)
def transcribe_audio(*, peer: abcs.InputPeer, msg_id: int) -> Request[abcs.messages.TranscribedAudio]:
    _buffer = bytearray(b'I\x9a\x9e&')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', msg_id)
    return Request(b'' + _buffer)
def rate_transcribed_audio(*, peer: abcs.InputPeer, msg_id: int, transcription_id: int, good: bool) -> Request[bool]:
    _buffer = bytearray(b'/\x07\x1d\x7f')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<iqI', msg_id, transcription_id, good)
    return Request(b'' + _buffer)
def get_custom_emoji_documents(*, document_id: Sequence[int]) -> Request[Sequence[abcs.Document]]:
    _buffer = bytearray(b'T\x0f\xab\xd9')
    _buffer += struct.pack('<ii', 0x1cb5c415, len(document_id))
    _buffer += struct.pack(f'<{len(document_id)}q', *document_id)
    return Request(b'' + _buffer)
def get_emoji_stickers(*, hash: int) -> Request[abcs.messages.AllStickers]:
    _buffer = bytearray(b'\x8f\xa1\xfc\xfb')
    _buffer += struct.pack('<q', hash)
    return Request(b'' + _buffer)
def get_featured_emoji_stickers(*, hash: int) -> Request[abcs.messages.FeaturedStickers]:
    _buffer = bytearray(b'6g\xcf\x0e')
    _buffer += struct.pack('<q', hash)
    return Request(b'' + _buffer)
def report_reaction(*, peer: abcs.InputPeer, id: int, reaction_peer: abcs.InputPeer) -> Request[bool]:
    _buffer = bytearray(b'v\xc0d?')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', id)
    reaction_peer._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_top_reactions(*, limit: int, hash: int) -> Request[abcs.messages.Reactions]:
    _buffer = bytearray(b'\xba%\x81\xbb')
    _buffer += struct.pack('<iq', limit, hash)
    return Request(b'' + _buffer)
def get_recent_reactions(*, limit: int, hash: int) -> Request[abcs.messages.Reactions]:
    _buffer = bytearray(b'\xb2\x1dF9')
    _buffer += struct.pack('<iq', limit, hash)
    return Request(b'' + _buffer)
def clear_recent_reactions() -> Request[bool]:
    _buffer = bytearray(b'\xb4\xef\xfe\x9d')
    return Request(b'' + _buffer)
def get_extended_media(*, peer: abcs.InputPeer, id: Sequence[int]) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\x14\x08\xf8\x84')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<ii', 0x1cb5c415, len(id))
    _buffer += struct.pack(f'<{len(id)}i', *id)
    return Request(b'' + _buffer)
def set_default_history_ttl(*, period: int) -> Request[bool]:
    _buffer = bytearray(b'E\x14\xb5\x9e')
    _buffer += struct.pack('<i', period)
    return Request(b'' + _buffer)
def get_default_history_ttl() -> Request[abcs.DefaultHistoryTtl]:
    _buffer = bytearray(b'\x88q\x8be')
    return Request(b'' + _buffer)
def send_bot_requested_peer(*, peer: abcs.InputPeer, msg_id: int, button_id: int, requested_peer: abcs.InputPeer) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\x1b\xd08\xfe')
    peer._write_boxed_to(_buffer)
    _buffer += struct.pack('<ii', msg_id, button_id)
    requested_peer._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_emoji_groups(*, hash: int) -> Request[abcs.messages.EmojiGroups]:
    _buffer = bytearray(b'[\xce\x88t')
    _buffer += struct.pack('<i', hash)
    return Request(b'' + _buffer)
def get_emoji_status_groups(*, hash: int) -> Request[abcs.messages.EmojiGroups]:
    _buffer = bytearray(b'\xcdV\xcd.')
    _buffer += struct.pack('<i', hash)
    return Request(b'' + _buffer)
def get_emoji_profile_photo_groups(*, hash: int) -> Request[abcs.messages.EmojiGroups]:
    _buffer = bytearray(b'\xf3H\xa5!')
    _buffer += struct.pack('<i', hash)
    return Request(b'' + _buffer)
def search_custom_emoji(*, emoticon: str, hash: int) -> Request[abcs.EmojiList]:
    _buffer = bytearray(b'\xd7\xc0\x11,')
    serialize_bytes_to(_buffer, emoticon.encode('utf-8'))
    _buffer += struct.pack('<q', hash)
    return Request(b'' + _buffer)
def toggle_peer_translations(*, disabled: bool, peer: abcs.InputPeer) -> Request[bool]:
    _buffer = bytearray(b'y\xb5|\xe4')
    flags = (1 if disabled else 0)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_bot_app(*, app: abcs.InputBotApp, hash: int) -> Request[abcs.messages.BotApp]:
    _buffer = bytearray(b'\xc3\xc5\xfd4')
    app._write_boxed_to(_buffer)
    _buffer += struct.pack('<q', hash)
    return Request(b'' + _buffer)
def request_app_web_view(*, write_allowed: bool, peer: abcs.InputPeer, app: abcs.InputBotApp, start_param: Optional[str], theme_params: Optional[abcs.DataJson], platform: str) -> Request[abcs.AppWebViewResult]:
    _buffer = bytearray(b'<;Z\x8c')
    flags = (1 if write_allowed else 0) | (0 if start_param is None else 2) | (0 if theme_params is None else 4)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    app._write_boxed_to(_buffer)
    if start_param is not None:
      serialize_bytes_to(_buffer, start_param.encode('utf-8'))
    if theme_params is not None:
      theme_params._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, platform.encode('utf-8'))
    return Request(b'' + _buffer)
def set_chat_wall_paper(*, peer: abcs.InputPeer, wallpaper: Optional[abcs.InputWallPaper], settings: Optional[abcs.WallPaperSettings], id: Optional[int]) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\xe1\xca\xfa\x8f')
    flags = (0 if wallpaper is None else 1) | (0 if settings is None else 4) | (0 if id is None else 2)
    _buffer += struct.pack('<I', flags)
    peer._write_boxed_to(_buffer)
    if wallpaper is not None:
      wallpaper._write_boxed_to(_buffer)
    if settings is not None:
      settings._write_boxed_to(_buffer)
    if id is not None:
      _buffer += struct.pack(f'<i', id)
    return Request(b'' + _buffer)
